@@ -4,6 +4,8 @@ fn main() {
             println!("cargo:rustc-link-search={}", p);
         }
     }
+
+    println!("cargo:rustc-flags=-l dylib=cassandra");
     println!("cargo:rustc-flags=-l dylib=crypto");
     println!("cargo:rustc-flags=-l dylib=ssl");
     println!("cargo:rustc-flags=-l dylib=stdc++");
@@ -14,5 +16,4 @@ fn main() {
     println!("cargo:rustc-link-search={}", "/usr/local/lib");
     println!("cargo:rustc-link-search={}", "/usr/lib64/");
     println!("cargo:rustc-link-search={}", "/usr/lib/");
-    println!("cargo:rustc-link-lib=static=cassandra_static");
 }
